/**
 * Zeroconf wrappers for finding HAP devices.
 */
/// <reference types="node" />
import { EventEmitter } from 'events';
export interface HapService {
    name: string;
    address: string;
    port: number;
    'c#': number;
    ff: number;
    id: string;
    md: string;
    pv: string;
    's#': number;
    sf: number;
    ci: number;
}
export default class IPDiscovery extends EventEmitter {
    private browser;
    private iface?;
    private services;
    /**
     * Initialize the IPDiscovery object.
     *
     * @param {string?} iface - Optional interface to bind to
     */
    constructor(iface?: string);
    /**
     * Convert a DNS-SD service record to a HAP service object.
     *
     * See Table 5-7
     *
     * @param {Object} service - Service record to convert
     */
    private static _serviceToHapService;
    /**
     * Start searching for HAP devices on the network.
     */
    start(): void;
    /**
     * List the currently known services.
     *
     * @returns {Object[]} Array of services
     */
    list(): HapService[];
    /**
     * Stop an ongoing discovery process.
     */
    stop(): void;
}
//# sourceMappingURL=ip-discovery.d.ts.map